@@ -20,6 +20,7 @@ from .handlers import (AuthorizationAreaHandler, ChangePasswordAdminHandler,
                        EmailAuthorizationHandler, LoginHandler, LogoutHandler,
                        SignUpHandler, ToggleAuthorizationHandler)
 from .orm import UserInfo
+from .apihandlers import CognitoAPIHandler
 
 
 class CognitoAuthenticator(Authenticator):
@@ -463,6 +464,7 @@ class CognitoAuthenticator(Authenticator):
             (r"/confirm/([^/]*)", EmailAuthorizationHandler),
             (r"/change-password", ChangePasswordHandler),
             (r"/change-password/([^/]+)", ChangePasswordAdminHandler),
+            (r"/api/cognito-token", CognitoAPIHandler),
         ]
         return native_handlers
 
